@@ -3,11 +3,37 @@ package namespace::clean;
 use warnings;
 use strict;
 
-our $VERSION = '0.25_01';
+our $VERSION = '0.25_02';
 our $STORAGE_VAR = '__NAMESPACE_CLEAN_STORAGE';
 
 use B::Hooks::EndOfScope 'on_scope_end';
-use namespace::clean::_Util qw( stash_for DEBUGGER_NEEDS_CV_RENAME DEBUGGER_NEEDS_CV_PIVOT );
+
+# FIXME This is a crock of shit, needs to go away
+# currently here to work around https://rt.cpan.org/Ticket/Display.html?id=74151
+# kill with fire when PS::XS is *finally* fixed
+BEGIN {
+  my $provider;
+
+  if ( $] < 5.008007 ) {
+    require Package::Stash::PP;
+    $provider = 'Package::Stash::PP';
+  }
+  else {
+    require Package::Stash;
+    $provider = 'Package::Stash';
+  }
+  eval <<"EOS" or die $@;
+
+sub stash_for (\$) {
+  $provider->new(\$_[0]);
+}
+
+1;
+
+EOS
+}
+
+use namespace::clean::_Util qw( DEBUGGER_NEEDS_CV_RENAME DEBUGGER_NEEDS_CV_PIVOT );
 
 # Built-in debugger CV-retrieval fixups necessary before perl 5.15.5:
 # since we are deleting the glob where the subroutine was originally
